@@ -1,6 +1,6 @@
 from fireworks import explicit_serialize
 
-from atomate.common.firetasks.glue_tasks import get_calc_loc, CopyFiles
+from atomate.common.firetasks.glue_tasks import CopyFiles, get_calc_loc
 
 __author__ = "Kiran Mathew"
 __email__ = "kmathew@lbl.gov"
@@ -18,7 +18,7 @@ class CopyFeffOutputs(CopyFiles):
             search for the most recent calc_loc with the matching name.
         calc_dir (str): path to dir that contains VASP output files.
         filesystem (str): remote filesystem. e.g. username@host
-        exclude_files (list): list fo filenames to be excluded when copying.
+        exclude_files (list): list of filenames to be excluded when copying.
     """
 
     optional_params = ["calc_loc", "calc_dir", "filesystem", "exclude_files"]
