@@ -2,7 +2,8 @@
 # electron density critical points with Critic2.
 
 from fireworks import Workflow
-from atomate.qchem.fireworks.core import FrequencyFlatteningOptimizeFW, CubeAndCritic2FW
+
+from atomate.qchem.fireworks.core import CubeAndCritic2FW, FrequencyFlatteningOptimizeFW
 from atomate.utils.utils import get_logger
 
 __author__ = "Samuel Blau"
@@ -35,23 +36,20 @@ def get_wf_FFopt_and_critic(
         molecule (Molecule): input molecule to be optimized and run.
         suffix (str): Workflow naming suffix
         qchem_input_params (dict): Specify kwargs for instantiating the input set parameters.
-                                   Basic uses would be to modify the default inputs of the set,
-                                   such as dft_rung, basis_set, pcm_dielectric, scf_algorithm,
-                                   or max_scf_cycles. See pymatgen/io/qchem/sets.py for default
-                                   values of all input parameters. For instance, if a user wanted
-                                   to use a more advanced DFT functional, include a pcm with a
-                                   dielectric of 30, and use a larger basis, the user would set
-                                   qchem_input_params = {"dft_rung": 5, "pcm_dielectric": 30,
-                                   "basis_set": "6-311++g**"}. However, more advanced customization
-                                   of the input is also possible through the overwrite_inputs key
-                                   which allows the user to directly modify the rem, pcm, smd, and
-                                   solvent dictionaries that QChemDictSet passes to inputs.py to
-                                   print an actual input file. For instance, if a user wanted to
-                                   set the sym_ignore flag in the rem section of the input file
-                                   to true, then they would set qchem_input_params = {"overwrite_inputs":
-                                   "rem": {"sym_ignore": "true"}}. Of course, overwrite_inputs
-                                   could be used in conjuction with more typical modifications,
-                                   as seen in the test_double_FF_opt workflow test.
+            Basic uses would be to modify the default inputs of the set, such as dft_rung,
+            basis_set, pcm_dielectric, scf_algorithm, or max_scf_cycles. See
+            pymatgen/io/qchem/sets.py for default values of all input parameters. For instance,
+            if a user wanted to use a more advanced DFT functional, include a pcm with a
+            dielectric of 30, and use a larger basis, the user would set qchem_input_params =
+            {"dft_rung": 5, "pcm_dielectric": 30, "basis_set": "6-311++g**"}. However, more
+            advanced customization of the input is also possible through the overwrite_inputs
+            key which allows the user to directly modify the rem, pcm, smd, and solvent
+            dictionaries that QChemDictSet passes to inputs.py to print an actual input file.
+            For instance, if a user wanted to set the sym_ignore flag in the rem section of the
+            input file to true, then they would set qchem_input_params = {"overwrite_inputs":
+            "rem": {"sym_ignore": "true"}}. Of course, overwrite_inputs could be used in
+            conjunction with more typical modifications, as seen in the test_double_FF_opt
+            workflow test.
         db_file (str): path to file containing the database credentials.
         kwargs (keyword arguments): additional kwargs to be passed to Workflow
 
