@@ -1,17 +1,16 @@
 import logging
 import os
-import sys
 import socket
+import sys
 from random import randint
 from time import time
 
-from pymongo import MongoClient
+from fireworks import Workflow
 from monty.json import MontyDecoder
 from monty.serialization import loadfn
-from pymatgen.core import Composition
-
-from fireworks import Workflow
 from pymatgen.alchemy.materials import TransformedStructure
+from pymatgen.core.composition import Composition
+from pymongo import MongoClient
 
 __author__ = "Anubhav Jain, Kiran Mathew"
 __email__ = "ajain@lbl.gov, kmathew@lbl.gov"
@@ -70,7 +69,7 @@ def get_mongolike(d, key):
     lead_key = key.split(".", 1)[0]
     try:
         lead_key = int(lead_key)  # for searching array data
-    except:
+    except Exception:
         pass
 
     if "." in key:
@@ -138,25 +137,24 @@ def get_logger(
 
 
 def get_meta_from_structure(structure):
-    if isinstance(structure, TransformedStructure):
-        structure = structure.final_structure
-
-    comp = structure.composition
-    elsyms = sorted({e.symbol for e in comp.elements})
-    meta = {
-        "nsites": structure.num_sites,
-        "elements": elsyms,
-        "nelements": len(elsyms),
-        "formula": comp.formula,
-        "formula_pretty": comp.reduced_formula,
-        "formula_reduced_abc": Composition(comp.reduced_formula).alphabetical_formula,
-        "formula_anonymous": comp.anonymized_formula,
-        "chemsys": "-".join(elsyms),
-        "is_ordered": structure.is_ordered,
-        "is_valid": structure.is_valid(),
-    }
-    return meta
+   if isinstance(structure, TransformedStructure):
+       structure = structure.final_structure
 
+   comp = structure.composition
+   elsyms = sorted({e.symbol for e in comp.elements})
+   meta = {
+       "nsites": structure.num_sites,
+       "elements": elsyms,
+       "nelements": len(elsyms),
+       "formula": comp.formula,
+       "formula_pretty": comp.reduced_formula,
+       "formula_reduced_abc": Composition(comp.reduced_formula).alphabetical_formula,
+       "formula_anonymous": comp.anonymized_formula,
+       "chemsys": "-".join(elsyms),
+       "is_ordered": structure.is_ordered,
+       "is_valid": structure.is_valid(),
+   }
+   return meta
 
 def get_fws_and_tasks(workflow, fw_name_constraint=None, task_name_constraint=None):
     """
@@ -302,7 +300,7 @@ def recursive_update(d, u):
     Recursive updates d with values from u
     Args:
         d (dict): dict to update
-        u (dict): updates to propogate
+        u (dict): updates to propagate
     """
 
     for k, v in u.items():
@@ -334,7 +332,7 @@ def get_uri(dir_name):
     fullpath = os.path.abspath(dir_name)
     try:
         hostname = socket.gethostbyaddr(socket.gethostname())[0]
-    except:
+    except Exception:
         hostname = socket.gethostname()
     return f"{hostname}:{fullpath}"
 
