@@ -4,38 +4,38 @@ Some of the changes are documented in this thread:
 https://groups.google.com/forum/#!topic/pymatgen/pQ-emBpeV5U
 """
 
+import datetime
+import glob
+import json
 import os
 import re
-import datetime
-from fnmatch import fnmatch
-from collections import OrderedDict
-import json
-import glob
 import traceback
 import warnings
+from collections import OrderedDict
+from fnmatch import fnmatch
 
+import numpy as np
 from monty.io import zopen
 from monty.json import jsanitize
 from monty.os.path import which
-
-import numpy as np
-
-from pymatgen.core.composition import Composition
-from pymatgen.core.structure import Structure
-from pymatgen.core.operations import SymmOp
-from pymatgen.electronic_structure.bandstructure import BandStructureSymmLine
-from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
-from pymatgen.io.vasp import BSVasprun, Vasprun, Outcar, Locpot
-from pymatgen.io.vasp.inputs import Poscar, Potcar, Incar, Kpoints
-from pymatgen.io.vasp.outputs import Chgcar
 from pymatgen.apps.borg.hive import AbstractDrone
 from pymatgen.command_line.bader_caller import bader_analysis_from_path
+from pymatgen.core.composition import Composition
+from pymatgen.core.operations import SymmOp
+from pymatgen.core.structure import Structure
+from pymatgen.electronic_structure.bandstructure import BandStructureSymmLine
+from pymatgen.io.vasp import BSVasprun, Locpot, Outcar, Vasprun
+from pymatgen.io.vasp.inputs import Incar, Kpoints, Poscar, Potcar
+from pymatgen.io.vasp.outputs import Chgcar
+from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
 
-from atomate.utils.utils import get_uri
-
-from atomate.utils.utils import get_logger
 from atomate import __version__ as atomate_version
-from atomate.vasp.config import STORE_VOLUMETRIC_DATA, STORE_ADDITIONAL_JSON, STORE_BADER
+from atomate.utils.utils import get_logger, get_uri
+from atomate.vasp.config import (
+    STORE_ADDITIONAL_JSON,
+    STORE_BADER,
+    STORE_VOLUMETRIC_DATA,
+)
 
 __author__ = "Kiran Mathew, Shyue Ping Ong, Shyam Dwaraknath, Anubhav Jain"
 __email__ = "kmathew@lbl.gov"
@@ -44,11 +44,10 @@ __version__ = "0.1.0"
 
 logger = get_logger(__name__)
 
-BADER_EXE_EXISTS = (which("bader") or which("bader.exe"))
+BADER_EXE_EXISTS = which("bader") or which("bader.exe")
 STORE_BADER = STORE_BADER and BADER_EXE_EXISTS
 
 
-
 class VaspDrone(AbstractDrone):
     """
     pymatgen-db VaspToDbTaskDrone with updated schema and documents processing methods.
@@ -145,9 +144,9 @@ class VaspDrone(AbstractDrone):
         store_additional_json=STORE_ADDITIONAL_JSON,
     ):
         """
-        Initialize a Vasp drone to parse vasp outputs
+        Initialize a Vasp drone to parse VASP outputs
         Args:
-            runs (list): Naming scheme for multiple calcuations in on folder e.g. ["relax1","relax2"].
+            runs (list): Naming scheme for multiple calculations in on folder e.g. ["relax1","relax2"].
              Can be subfolder or extension
             parse_dos (str or bool): Whether to parse the DOS. Can be "auto", True or False.
             "auto" will only parse DOS if NSW = 0, so there are no ionic steps
@@ -292,7 +291,7 @@ class VaspDrone(AbstractDrone):
                     "System time (sec)",
                     "Elapsed time (sec)",
                 ]:
-                    overall_run_stats[key] = sum([v[key] for v in run_stats.values()])
+                    overall_run_stats[key] = sum(v[key] for v in run_stats.values())
                 run_stats["overall"] = overall_run_stats
             except Exception:
                 logger.error(f"Bad run stats for {fullpath}.")
@@ -483,12 +482,12 @@ class VaspDrone(AbstractDrone):
             d["output"][k] = d["output"].pop(v)
 
         # Process bandstructure and DOS
-        if self.bandstructure_mode != False:  # noqa
+        if self.bandstructure_mode is not False:  # noqa
             bs = self.process_bandstructure(vrun)
             if bs:
                 d["bandstructure"] = bs
 
-        if self.parse_dos != False:  # noqa
+        if self.parse_dos is not False:  # noqa
             dos = self.process_dos(vrun)
             if dos:
                 d["dos"] = dos
@@ -674,9 +673,7 @@ class VaspDrone(AbstractDrone):
 
         # delta volume checks
         if abs(percent_delta_vol) > volume_change_threshold:
-            warning_msgs.append(
-                "Volume change > {}%".format(volume_change_threshold * 100)
-            )
+            warning_msgs.append(f"Volume change > {volume_change_threshold * 100}%")
 
         # max force and valid structure checks
         max_force = None
@@ -696,7 +693,7 @@ class VaspDrone(AbstractDrone):
             if calc["input"]["parameters"].get("NSW", 0) > 0:
 
                 drift = calc["output"]["outcar"].get("drift", [[0, 0, 0]])
-                max_drift = max([np.linalg.norm(d) for d in drift])
+                max_drift = max(np.linalg.norm(d) for d in drift)
                 ediffg = calc["input"]["parameters"].get("EDIFFG", None)
                 if ediffg and float(ediffg) < 0:
                     desired_force_convergence = -float(ediffg)
