@@ -7,37 +7,35 @@ from atomate.vasp.config import HALF_KPOINTS_FIRST_RELAX
 This module defines tasks that support running vasp in various ways.
 """
 
-import shutil
-import shlex
 import os
+import shlex
+import shutil
 import subprocess
 
-from pymatgen.io.vasp import Incar, Kpoints, Poscar, Potcar
-from pymatgen.io.vasp.sets import get_vasprun_outcar
-from pymatgen.electronic_structure.boltztrap import BoltztrapRunner
-
 from custodian import Custodian
 from custodian.vasp.handlers import (
-    VaspErrorHandler,
     AliasingErrorHandler,
-    MeshSymmetryErrorHandler,
-    UnconvergedErrorHandler,
-    MaxForceErrorHandler,
-    PotimErrorHandler,
+    DriftErrorHandler,
     FrozenJobErrorHandler,
+    IncorrectSmearingHandler,
+    LargeSigmaHandler,
+    MaxForceErrorHandler,
+    MeshSymmetryErrorHandler,
     NonConvergingErrorHandler,
     PositiveEnergyErrorHandler,
-    WalltimeHandler,
-    StdErrHandler,
-    DriftErrorHandler,
-    LargeSigmaHandler,
-    IncorrectSmearingHandler,
+    PotimErrorHandler,
     ScanMetalHandler,
+    StdErrHandler,
+    UnconvergedErrorHandler,
+    VaspErrorHandler,
+    WalltimeHandler,
 )
 from custodian.vasp.jobs import VaspJob, VaspNEBJob
-from custodian.vasp.validators import VasprunXMLValidator, VaspFilesValidator
-
-from fireworks import explicit_serialize, FiretaskBase, FWAction
+from custodian.vasp.validators import VaspFilesValidator, VasprunXMLValidator
+from fireworks import FiretaskBase, FWAction, explicit_serialize
+from pymatgen.electronic_structure.boltztrap import BoltztrapRunner
+from pymatgen.io.vasp import Incar, Kpoints, Poscar, Potcar
+from pymatgen.io.vasp.sets import get_vasprun_outcar
 
 from atomate.utils.utils import env_chk, get_logger
 from atomate.vasp.config import CUSTODIAN_MAX_ERRORS
@@ -83,7 +81,7 @@ class RunVaspCustodian(FiretaskBase):
     Optional params:
         job_type: (str) - choose from "normal" (default), "double_relaxation_run" (two consecutive
             jobs), "full_opt_run" (multiple optimizations), and "neb"
-        handler_group: (str or [ErrorHandler]) - group of handlers to use. See handler_groups dict in the code for
+        handler_group: (str | list[ErrorHandler]) - group of handlers to use. See handler_groups dict in the code or
             the groups and complete list of handlers in each group. Alternatively, you can
             specify a list of ErrorHandler objects.
         max_force_threshold: (float) - if >0, adds MaxForceErrorHandler. Not recommended for
@@ -281,9 +279,8 @@ class RunVaspCustodian(FiretaskBase):
             handlers.append(WalltimeHandler(wall_time=self["wall_time"]))
 
         if job_type == "neb":
-            validators = (
-                []
-            )  # CINEB vasprun.xml sometimes incomplete, file structure different
+            # CINEB vasprun.xml sometimes incomplete, file structure different
+            validators = []
         else:
             validators = [VasprunXMLValidator(), VaspFilesValidator()]
 
@@ -299,7 +296,13 @@ class RunVaspCustodian(FiretaskBase):
         c.run()
 
         if os.path.exists(zpath("custodian.json")):
-            stored_custodian_data = {"custodian": loadfn(zpath("custodian.json"))}
+            if os.path.exists(zpath("FW_offline.json")):
+                import json
+
+                with open(zpath("custodian.json")) as f:
+                    stored_custodian_data = {"custodian": json.load(f)}
+            else:
+                stored_custodian_data = {"custodian": loadfn(zpath("custodian.json"))}
             return FWAction(stored_data=stored_custodian_data)
 
 
