@@ -1,56 +1,53 @@
-import warnings
-
-from atomate.vasp.config import (
-    HALF_KPOINTS_FIRST_RELAX,
-    RELAX_MAX_FORCE,
-    VASP_CMD,
-    DB_FILE,
-    VDW_KERNEL_DIR,
-)
-
 """
 Defines standardized Fireworks that can be chained easily to perform various
 sequences of VASP calculations.
 """
+import warnings
 
 from fireworks import Firework
-
 from pymatgen.core import Structure
 from pymatgen.io.vasp.sets import (
-    MPRelaxSet,
-    MPScanRelaxSet,
     MITMDSet,
     MITRelaxSet,
-    MPStaticSet,
+    MPRelaxSet,
+    MPScanRelaxSet,
     MPSOCSet,
+    MPStaticSet,
 )
 
 from atomate.common.firetasks.glue_tasks import (
-    PassCalcLocs,
     CopyFiles,
     DeleteFiles,
     GzipDir,
+    PassCalcLocs,
+)
+from atomate.vasp.config import (
+    DB_FILE,
+    HALF_KPOINTS_FIRST_RELAX,
+    RELAX_MAX_FORCE,
+    VASP_CMD,
+    VDW_KERNEL_DIR,
 )
 from atomate.vasp.firetasks.glue_tasks import CopyVaspOutputs, pass_vasp_result
-from atomate.vasp.firetasks.neb_tasks import TransferNEBTask
-from atomate.vasp.firetasks.parse_outputs import VaspToDb, BoltztrapToDb
-from atomate.vasp.firetasks.run_calc import (
-    RunVaspCustodian,
-    RunBoltztrap,
+from atomate.vasp.firetasks.neb_tasks import (
+    TransferNEBTask,
+    WriteNEBFromEndpoints,
+    WriteNEBFromImages,
 )
+from atomate.vasp.firetasks.parse_outputs import BoltztrapToDb, VaspToDb
+from atomate.vasp.firetasks.run_calc import RunBoltztrap, RunVaspCustodian
 from atomate.vasp.firetasks.write_inputs import (
+    ModifyIncar,
     WriteNormalmodeDisplacedPoscar,
+    WriteScanRelaxFromPrev,
     WriteTransmutedStructureIOSet,
     WriteVaspFromIOSet,
+    WriteVaspFromIOSetFromInterpolatedPOSCAR,
     WriteVaspHSEBSFromPrev,
     WriteVaspNSCFFromPrev,
     WriteVaspSOCFromPrev,
     WriteVaspStaticFromPrev,
-    WriteVaspFromIOSetFromInterpolatedPOSCAR,
-    WriteScanRelaxFromPrev,
-    ModifyIncar,
 )
-from atomate.vasp.firetasks.neb_tasks import WriteNEBFromImages, WriteNEBFromEndpoints
 
 
 class OptimizeFW(Firework):
@@ -150,7 +147,7 @@ class ScanOptimizeFW(Firework):
         initialized with no parents, it will perform a GGA optimization of the provided
         structure using the PBESol functional. This GGA-relaxed structure is intended
         to be passed to a second instance of this Firework for optimization with SCAN.
-        (see workflow definition in SCAN_optimization.yaml)
+        (see workflow definition in metagga_optimization.yaml)
 
         Args:
             structure (Structure): Input structure. Note that for prev_calc_loc jobs, the structure
@@ -582,7 +579,7 @@ class NonSCFFW(Firework):
         t.append(
             VaspToDb(
                 db_file=db_file,
-                additional_fields={"task_label": name + " " + mode},
+                additional_fields={"task_label": f"{name} {mode}"},
                 parse_dos=(mode == "uniform"),
                 bandstructure_mode=mode,
             )
@@ -723,7 +720,7 @@ class RamanFW(Firework):
             user_incar_settings (dict): Parameters in INCAR to override
             **kwargs: Other kwargs that are passed to Firework.__init__.
         """
-        name = "{}_{}_{}".format(name, str(mode), str(displacement))
+        name = f"{name}_{str(mode)}_{str(displacement)}"
         fw_name = "{}-{}".format(
             structure.composition.reduced_formula if structure else "unknown", name
         )
