@@ -1,7 +1,6 @@
-from monty.json import MSONable, MontyDecoder
-
-from pymatgen.ext.matproj import MPRester
+from monty.json import MontyDecoder, MSONable
 from pymatgen.alchemy.filters import AbstractStructureFilter
+from pymatgen.ext.matproj import MPRester
 
 __author__ = "Anubhav Jain <ajain@lbl.gov>, Kiran Mathew <kmathew@lbl.gov>"
 
@@ -84,10 +83,10 @@ class SubmissionFilter(AbstractStructureFilter):
                             bs = mpr.get_bandstructure_by_material_id(mpid)
                             if bs:
                                 failures.append(f"NOT_IN_MP=False ({mpid})")
-                        except:
+                        except Exception:
                             pass
                 else:
-                    failures.append("NOT_IN_MP=False ({})".format(mpids[0]))
+                    failures.append(f"NOT_IN_MP=False ({mpids[0]})")
         return True if not failures else False
 
     def as_dict(self):
