@@ -1,35 +1,32 @@
 import os
-
-from atomate.vasp.fireworks.core import OptimizeFW, StaticFW
-from fireworks import Workflow, Firework
-from atomate.vasp.powerups import (
-    add_tags,
-    add_additional_fields_to_taskdocs,
-    add_wf_metadata,
-    add_common_powerups,
-)
-from atomate.vasp.workflows.base.core import get_wf
-from atomate.vasp.firetasks.parse_outputs import (
-    MagneticDeformationToDb,
-    MagneticOrderingsToDb,
-)
-
-from pymatgen.alchemy.materials import TransformedStructure
-
-from atomate.utils.utils import get_logger
-
-logger = get_logger(__name__)
-
-from atomate.vasp.config import VASP_CMD, DB_FILE, ADD_WF_METADATA
-
-from atomate.vasp.workflows.presets.scan import wf_scan_opt
 from uuid import uuid4
-from pymatgen.io.vasp.sets import MPRelaxSet
-from pymatgen.core import Lattice, Structure
+
+import numpy as np
+from fireworks import Firework, Workflow
+from pymatgen.alchemy.materials import TransformedStructure
 from pymatgen.analysis.magnetism.analyzer import (
     CollinearMagneticStructureAnalyzer,
     MagneticStructureEnumerator,
 )
+from pymatgen.analysis.structure_matcher import ElementComparator, StructureMatcher
+from pymatgen.core import Lattice, Structure
+from pymatgen.io.vasp.sets import MPRelaxSet
+
+from atomate.utils.utils import get_logger
+from atomate.vasp.config import ADD_WF_METADATA, DB_FILE, VASP_CMD
+from atomate.vasp.firetasks.parse_outputs import (
+    MagneticDeformationToDb,
+    MagneticOrderingsToDb,
+)
+from atomate.vasp.fireworks.core import OptimizeFW, StaticFW
+from atomate.vasp.powerups import (
+    add_additional_fields_to_taskdocs,
+    add_common_powerups,
+    add_tags,
+    add_wf_metadata,
+)
+from atomate.vasp.workflows.base.core import get_wf
+from atomate.vasp.workflows.presets.scan import wf_scan_opt
 
 __author__ = "Matthew Horton"
 __maintainer__ = "Matthew Horton"
@@ -42,6 +39,8 @@ __magnetic_ordering_wf_version__ = 2.0
 
 module_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)))
 
+logger = get_logger(__name__)
+
 
 def get_wf_magnetic_deformation(structure, c=None, vis=None):
     """
@@ -50,7 +49,7 @@ def get_wf_magnetic_deformation(structure, c=None, vis=None):
 
     Args:
         structure: input structure, must be structure with magnetic
-    elements, such that pymatgen will initalize ferromagnetic input by
+    elements, such that pymatgen will initialize ferromagnetic input by
     default -- see MPRelaxSet.yaml for list of default elements
         c: Workflow config dict, in the same format
     as in presets/core.py and elsewhere in atomate
@@ -414,7 +413,6 @@ def get_commensurate_orderings(magnetic_structures, energies):
     ordered_structures = [
         s for _, s in sorted(zip(energies, magnetic_structures), reverse=False)
     ]
-    ordered_energies = sorted(energies, reverse=False)
 
     # Ground state and 1st excited state
     gs_struct = ordered_structures[0]
@@ -467,7 +465,7 @@ def get_commensurate_orderings(magnetic_structures, energies):
     for s in mse.ordered_structures:
         try:
             s2 = sm.get_s2_like_s1(enum_struct, s)
-        except:
+        except Exception:
             s2 = None
         if s2 is not None:
             # Standardize magnetic structure
