@@ -5,7 +5,6 @@ This module defines the thermal expansion coefficient workflow.
 from uuid import uuid4
 
 from fireworks import Firework, Workflow
-
 from pymatgen.analysis.elasticity.strain import Deformation
 from pymatgen.io.vasp.sets import MPStaticSet
 
@@ -69,7 +68,7 @@ def get_wf_thermal_expansion(
             "'phonopy' package NOT installed. Required for the final analysis step."
         )
 
-    tag = tag or "thermal_expansion group: >>{}<<".format(str(uuid4()))
+    tag = tag or f"thermal_expansion group: >>{str(uuid4())}<<"
 
     deformations = [Deformation(defo_mat) for defo_mat in deformations]
 
