@@ -1,35 +1,34 @@
 from uuid import uuid4
 
 import numpy as np
-
-from pymatgen.io.vasp.sets import MPRelaxSet, MPStaticSet, MPHSERelaxSet
 from pymatgen.io.vasp.inputs import Kpoints
+from pymatgen.io.vasp.sets import MPHSERelaxSet, MPRelaxSet, MPStaticSet
 
 from atomate.vasp.config import (
+    ADD_WF_METADATA,
+    DB_FILE,
     SMALLGAP_KPOINT_MULTIPLY,
     STABILITY_CHECK,
     VASP_CMD,
-    DB_FILE,
-    ADD_WF_METADATA,
 )
 from atomate.vasp.powerups import (
+    add_common_powerups,
+    add_modify_incar,
     add_small_gap_multiply,
     add_stability_check,
-    add_modify_incar,
     add_wf_metadata,
-    add_common_powerups,
 )
+from atomate.vasp.workflows.base.bulk_modulus import get_wf_bulk_modulus
 from atomate.vasp.workflows.base.core import get_wf
 from atomate.vasp.workflows.base.elastic import get_wf_elastic_constant
-from atomate.vasp.workflows.base.raman import get_wf_raman_spectra
 from atomate.vasp.workflows.base.gibbs import get_wf_gibbs_free_energy
-from atomate.vasp.workflows.base.bulk_modulus import get_wf_bulk_modulus
-from atomate.vasp.workflows.base.thermal_expansion import get_wf_thermal_expansion
 from atomate.vasp.workflows.base.neb import (
     get_wf_neb_from_endpoints,
-    get_wf_neb_from_structure,
     get_wf_neb_from_images,
+    get_wf_neb_from_structure,
 )
+from atomate.vasp.workflows.base.raman import get_wf_raman_spectra
+from atomate.vasp.workflows.base.thermal_expansion import get_wf_thermal_expansion
 
 __author__ = "Anubhav Jain, Kiran Mathew"
 __email__ = "ajain@lbl.gov, kmathew@lbl.gov"
@@ -478,7 +477,7 @@ def wf_gibbs_free_energy(structure, c=None):
     deformations = c.get("DEFORMATIONS", defos)
     user_kpoints_settings = {"grid_density": 7000}
 
-    tag = "gibbs group: >>{}<<".format(str(uuid4()))
+    tag = f"gibbs group: >>{str(uuid4())}<<"
 
     # input set for structure optimization
     vis_relax = MPRelaxSet(structure, force_gamma=True)
@@ -585,7 +584,7 @@ def wf_bulk_modulus(structure, c=None):
         (np.identity(3) * (1 + x)).tolist() for x in np.linspace(-0.05, 0.05, 6)
     ]
 
-    tag = "bulk_modulus group: >>{}<<".format(str(uuid4()))
+    tag = f"bulk_modulus group: >>{str(uuid4())}<<"
 
     # input set for structure optimization
     vis_relax = MPRelaxSet(structure, force_gamma=True)
@@ -668,7 +667,7 @@ def wf_thermal_expansion(structure, c=None):
         (np.identity(3) * (1 + x)).tolist() for x in np.linspace(-0.1, 0.1, 10)
     ]
 
-    tag = "thermal_expansion group: >>{}<<".format(str(uuid4()))
+    tag = f"thermal_expansion group: >>{str(uuid4())}<<"
 
     # input set for structure optimization
     vis_relax = MPRelaxSet(structure, force_gamma=True)
